@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005, 2006, 2008 Brad Hards <bradh@frogmouth.net>
-// Copyright (C) 2005, 2007-2009, 2011-2014 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007-2009, 2011-2015 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Julien Rebetez <julienr@svn.gnome.org>
 // Copyright (C) 2008, 2010 Pino Toscano <pino@kde.org>
 // Copyright (C) 2008, 2010, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
@@ -32,6 +32,8 @@
 // Copyright (C) 2013 Adam Reichold <adamreichold@myopera.com>
 // Copyright (C) 2014 Bogdan Cristea <cristeab@gmail.com>
 // Copyright (C) 2015 Li Junling <lijunling@sina.com>
+// Copyright (C) 2015 André Guerreiro <aguerreiro1985@gmail.com>
+// Copyright (C) 2015 André Esser <bepandre@hotmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -452,6 +454,27 @@ GBool PDFDoc::checkEncryption(GooString *ownerPassword, GooString *userPassword)
   return ret;
 }
 
+std::vector<FormWidgetSignature*> PDFDoc::getSignatureWidgets()
+{
+  int num_pages = getNumPages();
+  FormPageWidgets *page_widgets = NULL;
+  std::vector<FormWidgetSignature*> widget_vector;
+
+  for (int i = 1; i <= num_pages; i++) {
+    Page *p = getCatalog()->getPage(i);
+    if (p) {
+      page_widgets = p->getFormWidgets();
+      for (int j = 0; page_widgets != NULL && j < page_widgets->getNumWidgets(); j++) {
+	if (page_widgets->getWidget(j)->getType() == formSignature) {
+	    widget_vector.push_back(static_cast<FormWidgetSignature*>(page_widgets->getWidget(j)));
+	}
+      }
+      delete page_widgets;
+    }
+  }
+  return widget_vector;
+}
+
 void PDFDoc::displayPage(OutputDev *out, int page,
 			 double hDPI, double vDPI, int rotate,
 			 GBool useMediaBox, GBool crop, GBool printing,
